@@ -1,6 +1,6 @@
 /*
  * Biloba
- * Copyright (C) 2004-2005 Guillaume Demougeot, Colin Leroy
+ * Copyright (C) 2004-2008 Guillaume Demougeot, Colin Leroy
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -160,37 +160,6 @@ static SDL_Surface *i_lfr = NULL, *i_len = NULL, *i_les = NULL;
 #define GAMELIST_MAX_Y(i) (GAMELIST_MIN_Y(i)+40)
 #define IN_GAMELIST(i,x,y) is_in_box(x,y,GAMELIST_MIN_X(i),GAMELIST_MIN_Y(i),GAMELIST_MAX_X(i),GAMELIST_MAX_Y(i))
 
-#if IS_DEMO
-static int get_file_age(const char *prefix, const char *name)
-{
-	int age = -1;
-	char *path = malloc(strlen(prefix)+ strlen (DIR_SEP) + strlen(name) + 1);
-	struct stat stats;
-
-	strcpy(path, prefix);
-	strcat(path, DIR_SEP);
-	strcat(path, name);
-	
-	if (stat(path, &stats) == 0 && S_ISREG(stats.st_mode))
-		age = time(NULL) - stats.st_ctime;
-	free(path);
-
-	return age;
-}
-
-int check_install_expiration(void) 
-{
-	int age = 0;
-	
-	age = get_file_age(PREFIX DIR_SEP "res", "nplay.png");
-	if (age < 0)
-		age = get_file_age(PREFIX, "nplay.png");
-	
-	return (age > MAX_AGE);
-
-}
-#endif
-
 void options_free_images(void)
 {
 	SDL_FreeSurface(i_num_players);
@@ -302,22 +271,6 @@ int get_options(void)
 	
 	SDL_FillRect(screen, NULL, 0x00000000);
 	SDL_UpdateRect(screen, 0, 0, 0, 0);
-#if IS_DEMO
-	if (check_install_expiration()) {
-		static SDL_Surface *demo_surface = NULL;
-		
-		if (demo_surface == NULL) {
-			demo_surface = biloba_load_image("demo.png");
-			assert(demo_surface != NULL);
-		}
-		put_image(demo_surface, 150, 150);
-		SDL_UpdateRect(screen, 0, 0, 0, 0);
-		SDL_Delay(20000);
-		SDL_FillRect(screen, NULL, 0x00000000);
-		SDL_UpdateRect(screen, 0, 0, 0, 0);
-		return -1;
-	}	
-#endif
 	
 	/* init num_players from nump */
 	num_players = nump - 2;
@@ -326,7 +279,6 @@ choose_again:
 	do {
 		SDL_Event event;
 		int i = 0;
-		int focus_changed = FALSE;
 
 		SDL_FillRect(screen, NULL, 0x00000000);
 
@@ -444,10 +396,7 @@ choose_again:
 				player_edit = 0;
 			} else if (key == SDLK_BACKSPACE && strlen(player_name[player_edit-1]) > 0) {
 				player_name[player_edit-1][strlen(player_name[player_edit-1])-1] = 0;
-			} else if ((key >= 'A' && key <= 'Z') ||
-				   (key >= 'a' && key <= 'z') ||
-				   (key >= '0' && key <= '9') ||
-				    key == ' ') {
+			} else {
 				append[0] = key;
 				if (strlen(player_name[player_edit-1]) < 9)
 					strcat(player_name[player_edit-1], append);
@@ -463,7 +412,7 @@ choose_again:
 
 			if (key == SDLK_RETURN || key == SDLK_KP_ENTER || key == SDLK_ESCAPE) {
 				gamename_edit = 0;
-			} else if (key == SDLK_BACKSPACE && strlen(gamename) > 0) {
+			} else if (key == SDLK_BACKSPACE && *gamename != '\0') {
 				gamename[strlen(gamename)-1] = 0;
 			} else if ((key >= 'A' && key <= 'Z') ||
 				   (key >= 'a' && key <= 'z') ||
@@ -486,7 +435,6 @@ choose_again:
 			if (num_players > 2) 
 				num_players = 0;
 			nump = num_players + 2;
-			focus_changed = TRUE;
 
 			if (network_create) {
 				player_type[0] = INPUT_LOCAL;
@@ -501,7 +449,7 @@ choose_again:
 			llist_free(netgames);
 			if (network_join)
 				netgames = net_get_games(nump);
-			else 
+			else
 				netgames = NULL;
 		}
 		
@@ -568,9 +516,13 @@ choose_again:
 			options_load_images();
 		}
 
-		if (network_join && netgames == NULL) {
+		if (network_join && !netgames) {
 			netgames = net_get_games(nump);
 		}
+		if (!network_join && netgames) {
+			llist_free(netgames);
+			netgames = NULL;
+		}
 		
 #ifdef DEBUG
 		printf("x %d, y %d\n", x, y);
@@ -580,6 +532,8 @@ choose_again:
 				LList *tmp = netgames;
 				printf("gamelist clicked %d - id %d\n",
 					i, netgames_ids[i]);
+				if (!tmp)
+					break;
 				if (netgames_ids[i] > 0) {
 					int k = 0;
 					Game *cur_game = NULL;
@@ -591,9 +545,9 @@ choose_again:
 					assert(cur_game->id == netgames_ids[i]);
 					
 					my_game_id = netgames_ids[i];
-					net_get_info(cur_game);
-					if (mynetname != NULL)
-						free(mynetname);
+					if (net_get_info(cur_game) < 0)
+						break;
+					free(mynetname);
 					mynetname = strdup(cur_game->name);
 					for (k = 0; k < cur_game->num_players; k++) {
 						if (k+1 == cur_game->first_avail_spot) {
@@ -656,7 +610,11 @@ connection_problem:
 	if (use_net && net_wait_ready(nump, player_name) < 0)
 		goto connection_problem;
 
+	if (!use_net)
+		net_close();
+
 	llist_for_each(netgames, game_free);
+	llist_free(netgames);
 	netgames = NULL;
 
 	SDL_FillRect(screen, NULL, 0x00000000);
